@@ -4,7 +4,9 @@ class Definitions:
     redshift = "REDSHIFT"
     postgres = "POSTGRES"
     druid = "DRUID"
-    supported_warehouses = [snowflake, bigquery, redshift, postgres, druid]
+    sql_server = "SQL_SERVER"
+    duck_db = "DUCK_DB"
+    supported_warehouses = [snowflake, bigquery, redshift, postgres, druid, sql_server, duck_db]
     supported_warehouses_text = ", ".join(supported_warehouses)
 
     does_not_exist = "__DOES_NOT_EXIST__"
