@@ -16,6 +16,8 @@ class ConnectionType:
     redshift = Definitions.redshift
     postgres = Definitions.postgres
     druid = Definitions.druid
+    sql_server = Definitions.sql_server
+    duck_db = Definitions.duck_db
 
 
 class BaseConnection:
@@ -152,6 +154,29 @@ class PostgresConnection(RedshiftConnection):
         self.schema = schema
 
 
+class DuckDBConnection(RedshiftConnection):
+    def __init__(
+        self,
+        name: str,
+        host: str,
+        user: str,
+        password: str,
+        port: int = 5432,
+        database: str = None,
+        schema: str = None,
+        **kwargs,
+    ) -> None:
+        self.type = ConnectionType.duck_db
+        self.name = name
+        self.host = host
+        self.port = port
+        self.user = user
+        self.username = user
+        self.password = password
+        self.database = database
+        self.schema = schema
+
+
 class DruidConnection(BaseConnection):
     def __init__(
         self,
@@ -181,6 +206,8 @@ class DruidConnection(BaseConnection):
         self.password = password
         self.path = path
         self.scheme = scheme
+        self.database = None
+        self.schema = None
 
     def to_dict(self):
         base = {
@@ -205,6 +232,57 @@ class DruidConnection(BaseConnection):
         return {key: attributes.get(key) for key in sort_order if attributes.get(key) is not None}
 
 
+class SQLServerConnection(BaseConnection):
+    def __init__(
+        self,
+        name: str,
+        host: str,
+        username: str = None,
+        user: str = None,
+        password: str = None,
+        port: int = 1433,
+        database: str = None,
+        schema: str = None,
+        **kwargs,
+    ) -> None:
+        self.type = ConnectionType.sql_server
+        self.name = name
+        self.host = host
+        self.port = port
+        if user and username:
+            raise ArgumentError(
+                "Received arguments for both user and username, "
+                "please send only one argument for the SQL Server user"
+            )
+        elif username:
+            self.user = username
+        elif user:
+            self.user = user
+        self.password = password
+        self.database = database
+        self.schema = schema
+
+    def to_dict(self):
+        base = {
+            "name": self.name,
+            "host": self.host,
+            "port": self.port,
+            "type": self.type,
+        }
+        if self.user:
+            base["user"] = self.user
+        if self.password:
+            base["password"] = self.password
+        return base
+
+    def printable_attributes(self):
+        attributes = deepcopy(self.to_dict())
+        attributes.pop("password")
+        attributes["name"] = self.name
+        sort_order = ["name", "type", "host", "port", "user"]
+        return {key: attributes.get(key) for key in sort_order if attributes.get(key) is not None}
+
+
 class BigQueryConnection(BaseConnection):
     def __init__(
         self, name: str, schema: str = None, credentials: str = None, keyfile: str = None, **kwargs
@@ -259,4 +337,6 @@ connection_class_lookup = {
     ConnectionType.bigquery: BigQueryConnection,
     ConnectionType.postgres: PostgresConnection,
     ConnectionType.druid: DruidConnection,
+    ConnectionType.sql_server: SQLServerConnection,
+    ConnectionType.duck_db: DuckDBConnection,
 }
